<?php

header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: *");
header('Content-Type: application/json; charset=utf-8');

include_once __DIR__ . '/../../config/db-connection.php';
include_once __DIR__ . '/../../config/https_environment.php';
include_once __DIR__ . '/../../utils/utils.php';

//CHECK API KEY
test_header_key();

$json = file_get_contents('php://input');
    
$json = json_decode($json,true);

if(empty($json['id_user'])){
    http_response_code(400);
    die(json_encode([
        'debug' => 'id_user'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

if(empty($json['id_unit'])){
    http_response_code(400);
    die(json_encode([
        'debug' => 'id_unit'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

$id_user = mysqli_real_escape_string($conn,$json['id_user']);
$id_unit = mysqli_real_escape_string($conn,$json['id_unit']);

// GET STUDENT GROUP
    $sql_group      = "SELECT g.level, u.editor FROM users u INNER JOIN `groups` g USING(id_group) WHERE u.id_user = '{$id_user}';";
    $result_group   = mysqli_query($conn,$sql_group);

    if(!$result_group){
        $error = mysqli_error($conn);
        http_response_code(500);
        mysqli_close($conn);
        die(json_encode([
            'debug' => $error
        ],JSON_UNESCAPED_UNICODE));
    }

    $row_group = mysqli_fetch_assoc($result_group);

    $group_level = $row_group['level'];
    $editor = $row_group['editor'];

// GET UNIT SECTIONS DATA
    $sql_sections = "SELECT 
        l.`label` as level_label,
        l.`order` as level_order,
        l.`class_name`,
        u.`order` as unit_order,
        u.`label` as unit_label,
        u.optional,
        s.`id_section`,
        s.`label` as section_label,
        s.`order` as section_order,
        s.unrestricted,
        s.free_access,
        s.icon
        FROM sections s
        INNER JOIN units u USING(id_unit)
        INNER JOIN levels l USING(id_level)
        WHERE u.`id_unit` = '${id_unit}' AND
        s.`status` = 1 AND
        u.`status` = 1 AND
        l.`status` = 1 AND
        (SELECT COUNT(*) FROM contents WHERE id_section = s.id_section AND status = 1) > 0
        ORDER BY s.`order` ASC, s.created_at ASC;
    ";

    $result_sections = mysqli_query($conn,$sql_sections);

    if(!$result_sections){
        http_response_code(500);
        die(json_encode([
            'debug' => $sql_sections
        ],JSON_UNESCAPED_UNICODE));
    }

    while($row_section = mysqli_fetch_assoc($result_sections)){
        $level_label    = $row_section['level_label'];
        $level_order    = $row_section['level_order'];
        $unit_label     = $row_section['unit_label'];
        $unit_order     = $row_section['unit_order'];
        $unit_optional  = $row_section['optional'];
        $color_class    = $row_section['class_name'];

        $section_id             = $row_section['id_section'];
        $section_label          = $row_section['section_label'];
        $section_order          = $row_section['section_order'];
        $section_icon           = $row_section['icon'];
        $section_unrestricted   = $row_section['unrestricted'];
        $section_free           = $row_section['free_access'];
        
        $force_permition = null;

        if($section_unrestricted == 1){
            $force_permition = true;
        }

        if($group_level == -1){
            if($section_free != 1){
                $force_permition = false;
            }
        }

        if($group_level > 2 || $editor == 1){
            $force_permition = true;
        }

        if(strtolower($section_label) == 'presentation'){
            continue;
        }
        
        $json_sections[$section_id] = [
            "name"      =>  $section_label,
            "order"     =>  $section_order,
            "iconClass" =>  $section_icon,
            "permition" =>  $force_permition
        ];
    }

// GET USER PROGRESS PERMITION
        $result_user_progress = get_user_progress($id_user,$url);
    
        if($result_user_progress['status'] != 200){
            http_response_code($result_user_progress['status']);
            die(json_encode([
                'debug' => $result_user_progress['debug']
            ], JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES));
        }
    
        $user_progress_json     = $result_user_progress['response']['user_progress'];
        $user_unit_progress     = json_decode($user_progress_json['unitProgress'],true);
        $user_progress          = $user_progress_json['progress'];

// TEST USER PROGRESS PERMITION

    // $res_last_content = get_last_content($conn);
    // if($res_last_content['status'] != 200){
    //     mysqli_close($conn);
    //     die(json_encode([
    //         'debug' => 'last_content'
    //     ], JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES));
    // }
    // $last_content_object = $res_last_content['response'];

    // $user_progress_authorized = check_user_permission_material([
    //     'level'     => $last_content_object['level']['order'],
    //     'unit'      => $last_content_object['unit']['order'],
    //     'section'   => $last_content_object['section']['order'],
    //     'content'   => $last_content_object['content']['order']
    // ],$user_progress);

    // if(!$user_progress_authorized){
    //     $user_progress_authorized = check_user_permission_material([
    //         'level' => $level_order,
    //         'unit'  => $unit_order
    //     ],$user_progress);
    
    //     if(!$user_progress_authorized){
    //         http_response_code(403);
    //         mysqli_close($conn);
    //         die(json_encode([
    //             'debug' => 'user progress 403'
    //         ], JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES));
    //     }
    // }
    
// CHECK IF USER CAN CLEAR PROGRESS
    $can_clear          = false;
    $need_to_choose     = false;
    $grade              = null;
    $approved           = null;
    
    if(isset($user_unit_progress[$id_unit]['progress'])){
        if(intval($user_unit_progress[$id_unit]['progress']) == 100){
            $can_clear = true;
            //TEST IF THIS IS THE LAST UNIT
            $res_last_content = get_last_content($conn);
            if($res_last_content['status'] != 200){
                mysqli_close($conn);
                die(json_encode([
                    'debug' => 'last_content'
                ], JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES));
            }
            $last_content_object = $res_last_content['response'];
            if($last_content_object['unit']['id'] != $id_unit){
                //CHECK IF THE STUDENT HAVE TO CHOOSE BETWEEN RESET OR CONTINUE
                if($level_order == intval($user_progress['level']) && $unit_order == intval($user_progress['unit'])){
                    $need_to_choose = true;
                    //GET AVERAGE
                    $res_average = get_average($conn);
                    if($res_average['status'] != 200){
                        mysqli_close($conn);
                        die(json_encode([
                            'debug' => 'average'
                        ], JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES));
                    }
                    $average = $res_average['response']['average'];

                    //TEST GRADE WITH AVERAGE
                    $grade = intval($user_unit_progress[$id_unit]['grade']);
                    $approved = $grade > $average;
                }else if($unit_optional == 1){
                    //GET AVERAGE
                    $res_average = get_average($conn);
                    if($res_average['status'] != 200){
                        mysqli_close($conn);
                        die(json_encode([
                            'debug' => 'average'
                        ], JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES));
                    }
                    $average = $res_average['response']['average'];
                    //TEST GRADE WITH AVERAGE
                    $grade = intval($user_unit_progress[$id_unit]['grade']);
                    $approved = $grade > $average;
                }
            }
        }
    }

// END OPERATION
    http_response_code(200);
    mysqli_commit($conn);
    mysqli_close($conn);
    die(json_encode([
        "levelName"     => $level_label,
        "levelOrder"    => $level_order,
        "unitName"      => $unit_label,
        "unitOrder"     => $unit_order,
        "colorClass"    => $color_class,
        "sections"      => $json_sections,
        "canClear"      => $can_clear,
        "needToChoose"  => $need_to_choose,
        "grade"         => $grade,
        "approved"      => $approved,
        "optional"      => $unit_optional
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));

?>