<?php

include_once __DIR__ . '/email_sender.php';



function json_curl($url_curl,$json){
    // Init curl
    $ch = curl_init($url_curl);
    // Setup request to send json via POST.
    $payload = json_encode($json);
    curl_setopt( $ch, CURLOPT_POSTFIELDS, $payload );
    curl_setopt( $ch, CURLOPT_HTTPHEADER, array('Content-Type:application/json'));
    // Return response instead of printing.
    curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
    // Send request.
    $result = curl_exec($ch);
    curl_close($ch);
    
    $return = [
        'status' =>  curl_getinfo($ch, CURLINFO_HTTP_CODE),
        'response' => $result
    ];

    return json_encode($return, JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES);
}

/**
 * @param json $content_permitions Os valores int da ordem dos levels,units,sections e contents. Levels é requisitado, units,sections e contents são opcionais
 * @param json $user_permitions Os valores int da ordem dos levels,units,sections e contents do progresso do usuário. Todos os valores são requisitados para a integridade do teste.
 * 
 * @return BOOL
 */
function check_user_permission_material($content_permitions,$user_permitions){

    if(empty($content_permitions['level'])){
        http_response_code(400);
        die();
    }

    $level_order = $content_permitions['level'];
    $unit_order = isset($content_permitions['unit']) ? $content_permitions['unit'] : 0;
    $section_order = isset($content_permitions['section']) ? $content_permitions['section'] : 0;
    $content_order = isset($content_permitions['content']) ? $content_permitions['content'] : 0;

    if(
        ($level_order < $user_permitions['level']) ||
        ($level_order == $user_permitions['level'] && $unit_order < $user_permitions['unit']) ||
        ($level_order == $user_permitions['level'] && $unit_order == $user_permitions['unit'] && $section_order < $user_permitions['section']) ||
        ($level_order == $user_permitions['level'] && $unit_order == $user_permitions['unit'] && $section_order == $user_permitions['section'] && $content_order <= $user_permitions['content'] )
    ){
        return true;
    }else{
        return false;
    }
}

function get_next_content_id($conn,$json){

    if(isset($json['content']['order'])){
        // NEXT CONTENT
            $sql_content = "SELECT
                c.`id_content`,
                c.`order`,
    
                s.id_section,
                s.order as order_section,
    
                u.id_unit,
                u.order as order_unit,
    
                l.id_level,
                l.order as order_level
    
                FROM contents c
                INNER JOIN sections s USING(id_section)
                INNER JOIN units u USING(id_unit)
                INNER JOIN levels l USING(id_level)
                WHERE c.`order` > {$json['content']['order']} AND 
                c.`id_section` = '{$json['section']['id']}' AND 
    
                c.`status` = 1 AND
                s.`status` = 1 AND
                s.`order` > 0 AND
                (u.`optional` = 0 OR u.`optional` IS NULL ) AND
                
                u.`status` = 1 AND
                l.`status` = 1 
    
                ORDER BY c.`order`
                LIMIT 1;
            ";
            
            $result_content = mysqli_query($conn,$sql_content);
    
            if(!$result_content){
                return [
                    'status' => 500,
                    'debug' => $sql_content
                ];
            }
    
            if(mysqli_num_rows($result_content) > 0){
                $row = mysqli_fetch_assoc($result_content);
    
                $id_content = $row['id_content'];
                $order_content = $row['order'];
    
                $id_section = $row['id_section'];
                $order_section = $row['order_section'];
    
                $id_unit = $row['id_unit'];
                $order_unit = $row['order_unit'];
    
                $id_level = $row['id_level'];
                $order_level = $row['order_level'];
                
                return [
                    'status' => 200,
                    'response' => [
                        'att_key' => 'content',
                        'content' => [
                            'id'    => $id_content,
                            'order' => $order_content
                        ],
                        'section' => [
                            'id'    => $id_section,
                            'order' => $order_section
                        ],
                        'unit' => [
                            'id'    => $id_unit,
                            'order' => $order_unit
                        ],
                        'level' => [
                            'id'    => $id_level,
                            'order' => $order_level
                        ],
                    ]
                ];
            }
    }


    if(isset($json['section']['order'])){
        // NEXT SECTION
            $sql_section = "SELECT
                c.`id_content`,
                c.`order` as order_content,
                s.id_section,
                s.order as order_section,
    
                u.id_unit,
                u.order as order_unit,
    
                l.id_level,
                l.order as order_level
                FROM contents c
                INNER JOIN sections s USING(id_section)
                INNER JOIN units u USING(id_unit)
                INNER JOIN levels l USING(id_level)
                WHERE s.`order` > {$json['section']['order']} AND
                s.id_unit = '{$json['unit']['id']}' AND
    
                c.`status` = 1 AND
                s.`status` = 1 AND
                                s.`order` > 0 AND
                (u.`optional` = 0 OR u.`optional` IS NULL ) AND
                u.`status` = 1 AND
                l.`status` = 1 
    
                ORDER BY s.`order` ASC, c.`order` ASC
                LIMIT 1;
            ";
    
            $result_section = mysqli_query($conn,$sql_section);
    
            if(!$result_section){
                return [
                    'status' => 500,
                    'debug' => $sql_section
                ];
            }
    
            if(mysqli_num_rows($result_section) > 0){
                $row = mysqli_fetch_assoc($result_section);
    
                $id_content = $row['id_content'];
                $order_content = $row['order_content'];
    
                $id_section = $row['id_section'];
                $order_section = $row['order_section'];
    
                $id_unit = $row['id_unit'];
                $order_unit = $row['order_unit'];
    
                $id_level = $row['id_level'];
                $order_level = $row['order_level'];
                
                return [
                    'status' => 200,
                    'response' => [
                        'att_key' => 'section',
                        'content' => [
                            'id'    => $id_content,
                            'order' => $order_content
                        ],
                        'section' => [
                            'id'    => $id_section,
                            'order' => $order_section
                        ],
                        'unit' => [
                            'id'    => $id_unit,
                            'order' => $order_unit
                        ],
                        'level' => [
                            'id'    => $id_level,
                            'order' => $order_level
                        ],
                    ]
                ];
            }
    }

    // NEXT UNIT
        $sql_unit = "SELECT
            c.`id_content`,
            c.`order` as order_content,

            s.id_section,
            s.order as order_section,

            u.id_unit,
            u.order as order_unit,

            l.id_level,
            l.order as order_level

            FROM contents c
            INNER JOIN sections s USING(id_section)
            INNER JOIN units u USING(id_unit)
            INNER JOIN levels l USING(id_level)
            WHERE u.`order` > {$json['unit']['order']} AND
            u.id_level = '{$json['level']['id']}' AND

            c.`status` = 1 AND
            s.`status` = 1 AND
                            s.`order` > 0 AND
                (u.`optional` = 0 OR u.`optional` IS NULL ) AND
            u.`status` = 1 AND
            l.`status` = 1 

            ORDER BY u.`order` ASC, s.`order` ASC, c.`order` ASC
            LIMIT 1;
        ";

        $result_unit = mysqli_query($conn,$sql_unit);

        if(!$result_unit){
            return [
                'status' => 500,
                'debug' => $sql_unit
            ];
        }

        if(mysqli_num_rows($result_unit) > 0){
            $row = mysqli_fetch_assoc($result_unit);

            $id_content = $row['id_content'];
            $order_content = $row['order_content'];

            $id_section = $row['id_section'];
            $order_section = $row['order_section'];

            $id_unit = $row['id_unit'];
            $order_unit = $row['order_unit'];

            $id_level = $row['id_level'];
            $order_level = $row['order_level'];
            
            return [
                'status' => 200,
                'response' => [
                    'att_key' => 'unit',
                    'content' => [
                        'id'    => $id_content,
                        'order' => $order_content
                    ],
                    'section' => [
                        'id'    => $id_section,
                        'order' => $order_section
                    ],
                    'unit' => [
                        'id'    => $id_unit,
                        'order' => $order_unit
                    ],
                    'level' => [
                        'id'    => $id_level,
                        'order' => $order_level
                    ],
                ]
            ];
        }
    // NEXT LEVEL
        $sql_level = "SELECT
            c.`id_content`,
            c.`order` as order_content,

            s.id_section,
            s.order as order_section,

            u.id_unit,
            u.order as order_unit,

            l.id_level,
            l.order as order_level

            FROM contents c
            INNER JOIN sections s ON c.id_section = s.id_section
            INNER JOIN units u ON s.id_unit = u.id_unit
            INNER JOIN levels l ON l.id_level = u.id_level
            WHERE l.`order` > {$json['level']['order']} AND

            c.`status` = 1 AND
            s.`status` = 1 AND
                            s.`order` > 0 AND
                (u.`optional` = 0 OR u.`optional` IS NULL ) AND
            u.`status` = 1 AND
            l.`status` = 1 

            ORDER BY l.`order` ASC, u.`order` ASC, s.`order` ASC, c.`order` ASC
            LIMIT 1;
        ";
        // die($sql_level);
        $result_level = mysqli_query($conn,$sql_level);

        if(!$result_level){
            return [
                'status' => 500,
                'debug' => $sql_level
            ];
        }

        if(mysqli_num_rows($result_level) > 0){
            $row = mysqli_fetch_assoc($result_level);

            $id_content = $row['id_content'];
            $order_content = $row['order_content'];

            $id_section = $row['id_section'];
            $order_section = $row['order_section'];

            $id_unit = $row['id_unit'];
            $order_unit = $row['order_unit'];

            $id_level = $row['id_level'];
            $order_level = $row['order_level'];
            
            return [
                'status' => 200,
                'response' => [
                    'att_key' => 'level',
                    'content' => [
                        'id'    => $id_content,
                        'order' => $order_content
                    ],
                    'section' => [
                        'id'    => $id_section,
                        'order' => $order_section
                    ],
                    'unit' => [
                        'id'    => $id_unit,
                        'order' => $order_unit
                    ],
                    'level' => [
                        'id'    => $id_level,
                        'order' => $order_level
                    ],
                ]
            ];
        }else{
            return [
                'status' => 200,
                'response' => [
                    'att_key' => 'end',
                    'content' => [
                        'id' => 'end'
                    ]
                ]
            ];
        }
}
function get_next_optional_content_id($conn,$json){

    if(isset($json['content']['order'])){
        // NEXT CONTENT
            $sql_content = "SELECT
                c.`id_content`,
                c.`order`,
    
                s.id_section,
                s.order as order_section,
    
                u.id_unit,
                u.order as order_unit,
    
                l.id_level,
                l.order as order_level
    
                FROM contents c
                INNER JOIN sections s USING(id_section)
                INNER JOIN units u USING(id_unit)
                INNER JOIN levels l USING(id_level)
                WHERE c.`order` > {$json['content']['order']} AND 
                c.`id_section` = '{$json['section']['id']}' AND 
    
                c.`status` = 1 AND
                s.`status` = 1 AND
                s.`order` > 0 AND
                
                u.`status` = 1 AND
                l.`status` = 1 
    
                ORDER BY c.`order`
                LIMIT 1;
            ";
            
            $result_content = mysqli_query($conn,$sql_content);
    
            if(!$result_content){
                return [
                    'status' => 500,
                    'debug' => $sql_content
                ];
            }
    
            if(mysqli_num_rows($result_content) > 0){
                $row = mysqli_fetch_assoc($result_content);
    
                $id_content = $row['id_content'];
                $order_content = $row['order'];
    
                $id_section = $row['id_section'];
                $order_section = $row['order_section'];
    
                $id_unit = $row['id_unit'];
                $order_unit = $row['order_unit'];
    
                $id_level = $row['id_level'];
                $order_level = $row['order_level'];
                
                return [
                    'status' => 200,
                    'response' => [
                        'att_key' => 'content',
                        'content' => [
                            'id'    => $id_content,
                            'order' => $order_content
                        ],
                        'section' => [
                            'id'    => $id_section,
                            'order' => $order_section
                        ],
                        'unit' => [
                            'id'    => $id_unit,
                            'order' => $order_unit
                        ],
                        'level' => [
                            'id'    => $id_level,
                            'order' => $order_level
                        ],
                    ]
                ];
            }
    }


    if(isset($json['section']['order'])){
        // NEXT SECTION
            $sql_section = "SELECT
                c.`id_content`,
                c.`order` as order_content,
                s.id_section,
                s.order as order_section,
    
                u.id_unit,
                u.order as order_unit,
    
                l.id_level,
                l.order as order_level
                FROM contents c
                INNER JOIN sections s USING(id_section)
                INNER JOIN units u USING(id_unit)
                INNER JOIN levels l USING(id_level)
                WHERE s.`order` > {$json['section']['order']} AND
                s.id_unit = '{$json['unit']['id']}' AND
    
                c.`status` = 1 AND
                s.`status` = 1 AND
                                s.`order` > 0 AND
                u.`status` = 1 AND
                l.`status` = 1 
    
                ORDER BY s.`order` ASC, c.`order` ASC
                LIMIT 1;
            ";
    
            $result_section = mysqli_query($conn,$sql_section);
    
            if(!$result_section){
                return [
                    'status' => 500,
                    'debug' => $sql_section
                ];
            }
    
            if(mysqli_num_rows($result_section) > 0){
                $row = mysqli_fetch_assoc($result_section);
    
                $id_content = $row['id_content'];
                $order_content = $row['order_content'];
    
                $id_section = $row['id_section'];
                $order_section = $row['order_section'];
    
                $id_unit = $row['id_unit'];
                $order_unit = $row['order_unit'];
    
                $id_level = $row['id_level'];
                $order_level = $row['order_level'];
                
                return [
                    'status' => 200,
                    'response' => [
                        'att_key' => 'section',
                        'content' => [
                            'id'    => $id_content,
                            'order' => $order_content
                        ],
                        'section' => [
                            'id'    => $id_section,
                            'order' => $order_section
                        ],
                        'unit' => [
                            'id'    => $id_unit,
                            'order' => $order_unit
                        ],
                        'level' => [
                            'id'    => $id_level,
                            'order' => $order_level
                        ],
                    ]
                ];
            }
    }

    // NEXT UNIT
        $sql_unit = "SELECT
            c.`id_content`,
            c.`order` as order_content,

            s.id_section,
            s.order as order_section,

            u.id_unit,
            u.order as order_unit,

            l.id_level,
            l.order as order_level

            FROM contents c
            INNER JOIN sections s USING(id_section)
            INNER JOIN units u USING(id_unit)
            INNER JOIN levels l USING(id_level)
            WHERE u.`order` > {$json['unit']['order']} AND
            u.id_level = '{$json['level']['id']}' AND

            c.`status` = 1 AND
            s.`status` = 1 AND
            s.`order` > 0 AND
            u.`status` = 1 AND
            l.`status` = 1 

            ORDER BY u.`order` ASC, s.`order` ASC, c.`order` ASC
            LIMIT 1;
        ";

        $result_unit = mysqli_query($conn,$sql_unit);

        if(!$result_unit){
            return [
                'status' => 500,
                'debug' => $sql_unit
            ];
        }

        if(mysqli_num_rows($result_unit) > 0){
            $row = mysqli_fetch_assoc($result_unit);

            $id_content = $row['id_content'];
            $order_content = $row['order_content'];

            $id_section = $row['id_section'];
            $order_section = $row['order_section'];

            $id_unit = $row['id_unit'];
            $order_unit = $row['order_unit'];

            $id_level = $row['id_level'];
            $order_level = $row['order_level'];
            
            return [
                'status' => 200,
                'response' => [
                    'att_key' => 'unit',
                    'content' => [
                        'id'    => $id_content,
                        'order' => $order_content
                    ],
                    'section' => [
                        'id'    => $id_section,
                        'order' => $order_section
                    ],
                    'unit' => [
                        'id'    => $id_unit,
                        'order' => $order_unit
                    ],
                    'level' => [
                        'id'    => $id_level,
                        'order' => $order_level
                    ],
                ]
            ];
        }
    // NEXT LEVEL
        $sql_level = "SELECT
            c.`id_content`,
            c.`order` as order_content,

            s.id_section,
            s.order as order_section,

            u.id_unit,
            u.order as order_unit,

            l.id_level,
            l.order as order_level

            FROM contents c
            INNER JOIN sections s ON c.id_section = s.id_section
            INNER JOIN units u ON s.id_unit = u.id_unit
            INNER JOIN levels l ON l.id_level = u.id_level
            WHERE l.`order` > {$json['level']['order']} AND

            c.`status` = 1 AND
            s.`status` = 1 AND
            s.`order` > 0 AND
            u.`status` = 1 AND
            l.`status` = 1 

            ORDER BY l.`order` ASC, u.`order` ASC, s.`order` ASC, c.`order` ASC
            LIMIT 1;
        ";
        // die($sql_level);
        $result_level = mysqli_query($conn,$sql_level);

        if(!$result_level){
            return [
                'status' => 500,
                'debug' => $sql_level
            ];
        }

        if(mysqli_num_rows($result_level) > 0){
            $row = mysqli_fetch_assoc($result_level);

            $id_content = $row['id_content'];
            $order_content = $row['order_content'];

            $id_section = $row['id_section'];
            $order_section = $row['order_section'];

            $id_unit = $row['id_unit'];
            $order_unit = $row['order_unit'];

            $id_level = $row['id_level'];
            $order_level = $row['order_level'];
            
            return [
                'status' => 200,
                'response' => [
                    'att_key' => 'level',
                    'content' => [
                        'id'    => $id_content,
                        'order' => $order_content
                    ],
                    'section' => [
                        'id'    => $id_section,
                        'order' => $order_section
                    ],
                    'unit' => [
                        'id'    => $id_unit,
                        'order' => $order_unit
                    ],
                    'level' => [
                        'id'    => $id_level,
                        'order' => $order_level
                    ],
                ]
            ];
        }else{
            return [
                'status' => 200,
                'response' => [
                    'att_key' => 'end',
                    'content' => [
                        'id' => 'end'
                    ]
                ]
            ];
        }
}

function get_next_content_page_id($conn,$json){

    if(isset($json['content']['order'])){
        // NEXT CONTENT
            $sql_content = "SELECT
                c.`id_content`,
                c.`order`,
    
                s.id_section,
                s.order as order_section,
    
                u.id_unit,
                u.order as order_unit,
    
                l.id_level,
                l.order as order_level
    
                FROM contents c
                INNER JOIN sections s USING(id_section)
                INNER JOIN units u USING(id_unit)
                INNER JOIN levels l USING(id_level)
                WHERE c.`order` > {$json['content']['order']} AND 
                c.`id_section` = '{$json['section']['id']}' AND 
    
                c.`status` = 1 AND
                s.`status` = 1 AND
                
                u.`status` = 1 AND
                u.`status` = 1 AND
                l.`status` = 1 
    
                ORDER BY c.`order`
                LIMIT 1;
            ";
            
            $result_content = mysqli_query($conn,$sql_content);
    
            if(!$result_content){
                return [
                    'status' => 500,
                    'debug' => $sql_content
                ];
            }
    
            if(mysqli_num_rows($result_content) > 0){
                $row = mysqli_fetch_assoc($result_content);
    
                $id_content = $row['id_content'];
                $order_content = $row['order'];
    
                $id_section = $row['id_section'];
                $order_section = $row['order_section'];
    
                $id_unit = $row['id_unit'];
                $order_unit = $row['order_unit'];
    
                $id_level = $row['id_level'];
                $order_level = $row['order_level'];
                
                return [
                    'status' => 200,
                    'response' => [
                        'att_key' => 'content',
                        'content' => [
                            'id'    => $id_content,
                            'order' => $order_content
                        ],
                        'section' => [
                            'id'    => $id_section,
                            'order' => $order_section
                        ],
                        'unit' => [
                            'id'    => $id_unit,
                            'order' => $order_unit
                        ],
                        'level' => [
                            'id'    => $id_level,
                            'order' => $order_level
                        ],
                    ]
                ];
            }
    }

    if(isset($json['section']['order'])){
        // NEXT SECTION
            $sql_section = "SELECT
                c.`id_content`,
                c.`order` as order_content,
                s.id_section,
                s.order as order_section,
    
                u.id_unit,
                u.order as order_unit,
    
                l.id_level,
                l.order as order_level
                FROM contents c
                INNER JOIN sections s USING(id_section)
                INNER JOIN units u USING(id_unit)
                INNER JOIN levels l USING(id_level)
                WHERE s.`order` > {$json['section']['order']} AND
                s.id_unit = '{$json['unit']['id']}' AND
    
                c.`status` = 1 AND
                s.`status` = 1 AND
                u.`status` = 1 AND
                l.`status` = 1 
    
                ORDER BY s.`order` ASC, c.`order` ASC
                LIMIT 1;
            ";
    
            $result_section = mysqli_query($conn,$sql_section);
    
            if(!$result_section){
                return [
                    'status' => 500,
                    'debug' => $sql_section
                ];
            }
    
            if(mysqli_num_rows($result_section) > 0){
                $row = mysqli_fetch_assoc($result_section);
    
                $id_content = $row['id_content'];
                $order_content = $row['order_content'];
    
                $id_section = $row['id_section'];
                $order_section = $row['order_section'];
    
                $id_unit = $row['id_unit'];
                $order_unit = $row['order_unit'];
    
                $id_level = $row['id_level'];
                $order_level = $row['order_level'];
                
                return [
                    'status' => 200,
                    'response' => [
                        'att_key' => 'section',
                        'content' => [
                            'id'    => $id_content,
                            'order' => $order_content
                        ],
                        'section' => [
                            'id'    => $id_section,
                            'order' => $order_section
                        ],
                        'unit' => [
                            'id'    => $id_unit,
                            'order' => $order_unit
                        ],
                        'level' => [
                            'id'    => $id_level,
                            'order' => $order_level
                        ],
                    ]
                ];
            }
    }

    // NEXT UNIT
        $sql_unit = "SELECT
            c.`id_content`,
            c.`order` as order_content,

            s.id_section,
            s.order as order_section,

            u.id_unit,
            u.order as order_unit,

            l.id_level,
            l.order as order_level

            FROM contents c
            INNER JOIN sections s USING(id_section)
            INNER JOIN units u USING(id_unit)
            INNER JOIN levels l USING(id_level)
            WHERE u.`order` > {$json['unit']['order']} AND
            u.id_level = '{$json['level']['id']}' AND

            c.`status` = 1 AND
            s.`status` = 1 AND
            u.`status` = 1 AND
            l.`status` = 1 

            ORDER BY u.`order` ASC, s.`order` ASC, c.`order` ASC
            LIMIT 1;
        ";

        $result_unit = mysqli_query($conn,$sql_unit);

        if(!$result_unit){
            return [
                'status' => 500,
                'debug' => $sql_unit
            ];
        }

        if(mysqli_num_rows($result_unit) > 0){
            $row = mysqli_fetch_assoc($result_unit);

            $id_content = $row['id_content'];
            $order_content = $row['order_content'];

            $id_section = $row['id_section'];
            $order_section = $row['order_section'];

            $id_unit = $row['id_unit'];
            $order_unit = $row['order_unit'];

            $id_level = $row['id_level'];
            $order_level = $row['order_level'];
            
            return [
                'status' => 200,
                'response' => [
                    'att_key' => 'unit',
                    'content' => [
                        'id'    => $id_content,
                        'order' => $order_content
                    ],
                    'section' => [
                        'id'    => $id_section,
                        'order' => $order_section
                    ],
                    'unit' => [
                        'id'    => $id_unit,
                        'order' => $order_unit
                    ],
                    'level' => [
                        'id'    => $id_level,
                        'order' => $order_level
                    ],
                ]
            ];
        }
    // NEXT LEVEL
        $sql_level = "SELECT
            c.`id_content`,
            c.`order` as order_content,

            s.id_section,
            s.order as order_section,

            u.id_unit,
            u.order as order_unit,

            l.id_level,
            l.order as order_level

            FROM contents c
            INNER JOIN sections s ON c.id_section = s.id_section
            INNER JOIN units u ON s.id_unit = u.id_unit
            INNER JOIN levels l ON l.id_level = u.id_level
            WHERE l.`order` > {$json['level']['order']} AND

            c.`status` = 1 AND
            s.`status` = 1 AND
            u.`status` = 1 AND
            l.`status` = 1 

            ORDER BY l.`order` ASC, u.`order` ASC, s.`order` ASC, c.`order` ASC
            LIMIT 1;
        ";
        // die($sql_level);
        $result_level = mysqli_query($conn,$sql_level);

        if(!$result_level){
            return [
                'status' => 500,
                'debug' => $sql_level
            ];
        }

        if(mysqli_num_rows($result_level) > 0){
            $row = mysqli_fetch_assoc($result_level);

            $id_content = $row['id_content'];
            $order_content = $row['order_content'];

            $id_section = $row['id_section'];
            $order_section = $row['order_section'];

            $id_unit = $row['id_unit'];
            $order_unit = $row['order_unit'];

            $id_level = $row['id_level'];
            $order_level = $row['order_level'];
            
            return [
                'status' => 200,
                'response' => [
                    'att_key' => 'level',
                    'content' => [
                        'id'    => $id_content,
                        'order' => $order_content
                    ],
                    'section' => [
                        'id'    => $id_section,
                        'order' => $order_section
                    ],
                    'unit' => [
                        'id'    => $id_unit,
                        'order' => $order_unit
                    ],
                    'level' => [
                        'id'    => $id_level,
                        'order' => $order_level
                    ],
                ]
            ];
        }else{
            return [
                'status' => 200,
                'response' => [
                    'att_key' => 'end',
                    'content' => [
                        'id' => 'end'
                    ]
                ]
            ];
        }
}

function get_first_content_id_by_unit($conn,$json){
    // GET FIRST CONTENT

        if(empty($json['unit']['id'])){
            $sql_unit = "SELECT
                c.`id_content`,
                c.`order` as order_content,

                s.id_section,
                s.order as order_section,

                u.id_unit,
                u.order as order_unit,

                l.id_level,
                l.order as order_level

                FROM contents c
                INNER JOIN sections s USING(id_section)
                INNER JOIN units u USING(id_unit)
                INNER JOIN levels l USING(id_level)
                WHERE u.`order` = '{$json['unit']['order']}' AND
                l.order = '{$json['level']['order']}' AND

                c.`status` = 1 AND
                s.`status` = 1 AND
                                s.`order` > 0 AND
                (u.`optional` = 0 OR u.`optional` IS NULL ) AND
                u.`status` = 1 AND
                l.`status` = 1 

                ORDER BY u.`order` DESC, s.`order` ASC, c.`order` ASC
                LIMIT 1;
            ";
        }else{
            $sql_unit = "SELECT
                c.`id_content`,
                c.`order` as order_content,

                s.id_section,
                s.order as order_section,

                u.id_unit,
                u.order as order_unit,

                l.id_level,
                l.order as order_level

                FROM contents c
                INNER JOIN sections s USING(id_section)
                INNER JOIN units u USING(id_unit)
                INNER JOIN levels l USING(id_level)
                WHERE u.`id_unit` = '{$json['unit']['id']}' AND
                l.id_level = '{$json['level']['id']}' AND

                c.`status` = 1 AND
                s.`status` = 1 AND
                                s.`order` > 0 AND
                (u.`optional` = 0 OR u.`optional` IS NULL ) AND
                u.`status` = 1 AND
                l.`status` = 1 

                ORDER BY u.`order` DESC, s.`order` ASC, c.`order` ASC
                LIMIT 1;
            ";
        }


        $result_unit = mysqli_query($conn,$sql_unit);

        if(!$result_unit){
            return [
                'status' => 500,
                'debug' => $sql_unit
            ];
        }

        if(mysqli_num_rows($result_unit) > 0){
            $row = mysqli_fetch_assoc($result_unit);

            $id_content = $row['id_content'];
            $order_content = $row['order_content'];

            $id_section = $row['id_section'];
            $order_section = $row['order_section'];

            $id_unit = $row['id_unit'];
            $order_unit = $row['order_unit'];

            $id_level = $row['id_level'];
            $order_level = $row['order_level'];
            
            return [
                'status' => 200,
                'response' => [
                    'att_key' => 'unit',
                    'content' => [
                        'id'    => $id_content,
                        'order' => $order_content
                    ],
                    'section' => [
                        'id'    => $id_section,
                        'order' => $order_section
                    ],
                    'unit' => [
                        'id'    => $id_unit,
                        'order' => $order_unit
                    ],
                    'level' => [
                        'id'    => $id_level,
                        'order' => $order_level
                    ],
                ]
            ];
        }
}

function get_user_progress($id_user,$url){
    // GET USER PROGRESS PERMITION
    $result_user_progress = json_curl(
        "{$url}/usuarios/progressao/buscar-progresso.php",
        ['id_user' => $id_user]
    );
    try{
        $return_user_progress = json_decode($result_user_progress, true);
        if(gettype($return_user_progress) != 'array'){
            return [
                'status' => 500,
                'debug' => 'curl not array',
                'response' => []
            ];
        }

        if($return_user_progress['status'] != 200){
            return [
                'status' => $return_user_progress['status'],
                'debug' => "{$url}/usuarios/progressao/buscar-progresso.php",
                'response' => []
            ];
        }

        $user_progress = json_decode($return_user_progress['response'], true);

        return [
            'status' => 200,
            'response' => [
                'user_progress' => $user_progress
            ]
        ];

    }catch(Exception $e){
        return [
            'status' => 500,
            'debug' => $e,
            'response' => []
        ];
    }
}

function fetch_user_progress($id_user,$conn){
    $sql_progress = "SELECT
        up.level_order,
        up.unit_order,
        up.section_order,
        up.content_order,
        up.units_progress,
        u.id_unit,
        u.id_level
        FROM user_progress up
        INNER JOIN levels l ON up.level_order = l.order 
        INNER JOIN units u ON l.id_level = u.id_level 
        WHERE up.id_user = '{$id_user}'
    ";

    $result_progress = mysqli_query($conn,$sql_progress);

    if(!$result_progress){
        http_response_code(500);
        die(json_encode([
            'debug' => 'erro na query, ' . $sql_progress
        ],JSON_UNESCAPED_UNICODE));
    }

    $json_progress = [];

    $row_progress = mysqli_fetch_assoc($result_progress);

    $json_progress['id_unit'] = $row_progress['id_unit'];
    $json_progress['id_level'] = $row_progress['id_level'];

    $json_progress['progress']['unit'] = $row_progress['unit_order'];
    $json_progress['progress']['level'] = $row_progress['level_order'];
    $json_progress['progress']['unit'] = $row_progress['unit_order'];
    $json_progress['progress']['section'] = $row_progress['section_order'];
    $json_progress['progress']['content'] = $row_progress['content_order'];

    $json_progress['unitProgress'] = $row_progress['units_progress'];

    return $json_progress;
}


function test_permition($conn,$id_user,$level){
    $sql_get = "SELECT 
    g.level
    FROM users u
    INNER JOIN `groups` g USING(id_group)
    WHERE u.id_user = '{$id_user}';";

    $result_get = mysqli_query($conn,$sql_get);

    if(!$result_get){
        return [
            'status' => 500,
            'response' => [],
            'debug' => $sql_get
        ];        
    }

    $row_get = mysqli_fetch_assoc($result_get);

    $user_level = $row_get['level'];

    if($user_level < $level){
        return [
            'status'    => 200,
            'response'  => [
                'permition' => false
            ]
        ];
    }else{
        return [
            'status'    => 200,
            'response'  => [
                'permition' => true
            ]
        ];
    }

}

function get_average($conn){
    $sql_get = "SELECT average FROM current_average ORDER BY average ASC LIMIT 1;";

    $result_get = mysqli_query($conn,$sql_get);

    if(!$result_get){
        return [
            'status' => 500,
            'response' => [],
            'debug' => $sql_get
        ];        
    }

    $row_get = mysqli_fetch_assoc($result_get);

    $average = $row_get['average'];

    return [
        'status'    => 200,
        'response'  => [
            'average' => $average
        ]
    ];
    

}

function get_last_content($conn){
    $sql_get = "SELECT
    c.`id_content`,
    c.`order` as order_content,

    s.id_section,
    s.order as order_section,

    u.id_unit,
    u.order as order_unit,

    l.id_level,
    l.order as order_level

    FROM contents c
    INNER JOIN sections s ON c.id_section = s.id_section
    INNER JOIN units u ON s.id_unit = u.id_unit
    INNER JOIN levels l ON l.id_level = u.id_level
    WHERE
    c.`status` = 1 AND
    s.`status` = 1 AND
                    s.`order` > 0 AND
                (u.`optional` = 0 OR u.`optional` IS NULL ) AND
    u.`status` = 1 AND
    l.`status` = 1 

    ORDER BY l.`order` DESC, u.`order` DESC, s.`order` DESC, c.`order` DESC
    LIMIT 1;
    ";

    $result_get = mysqli_query($conn,$sql_get);

    if(!$result_get){
        return [
            'status' => 500,
            'response' => [],
            'debug' => $sql_get
        ];        
    }

    $row = mysqli_fetch_assoc($result_get);

    $id_content = $row['id_content'];
    $order_content = $row['order_content'];

    $id_section = $row['id_section'];
    $order_section = $row['order_section'];

    $id_unit = $row['id_unit'];
    $order_unit = $row['order_unit'];

    $id_level = $row['id_level'];
    $order_level = $row['order_level'];
    
    return [
        'status' => 200,
        'response' => [
            'content' => [
                'id'    => $id_content,
                'order' => $order_content
            ],
            'section' => [
                'id'    => $id_section,
                'order' => $order_section
            ],
            'unit' => [
                'id'    => $id_unit,
                'order' => $order_unit
            ],
            'level' => [
                'id'    => $id_level,
                'order' => $order_level
            ],
        ]
    ];
    

}

function get_closest_content_by_next_level($conn,$level_order){
    //SELECT NEXT UNIT
    $sql_next_unit = "SELECT
        c.`id_content`,
        c.`order` as order_content,

        s.id_section,
        s.order as order_section,

        u.id_unit,
        u.order as order_unit,

        l.id_level,
        l.order as order_level

        FROM contents c
        INNER JOIN sections s USING(id_section)
        INNER JOIN units u USING(id_unit)
        INNER JOIN levels l USING(id_level)
        WHERE l.`order` > {$level_order} AND

        c.`status` = 1 AND
        s.`status` = 1 AND
                        s.`order` > 0 AND
                (u.`optional` = 0 OR u.`optional` IS NULL ) AND
        u.`status` = 1 AND
        l.`status` = 1 

        ORDER BY l.`order` ASC, u.`order` ASC, s.`order` ASC, c.`order` ASC
        LIMIT 1
    ";
    
    $result_next_unit = mysqli_query($conn,$sql_next_unit);

    if(!$result_next_unit){
        return [
            'status' => 500,
            'response' => [],
            'debug' => $sql_next_unit
        ];        
    }

    $row = mysqli_fetch_assoc($result_next_unit);

    $id_content = $row['id_content'];
    $order_content = $row['order_content'];

    $id_section = $row['id_section'];
    $order_section = $row['order_section'];

    $id_unit = $row['id_unit'];
    $order_unit = $row['order_unit'];

    $id_level = $row['id_level'];
    $order_level = $row['order_level'];
    
    return [
        'status' => 200,
        'response' => [
            'content' => [
                'id'    => $id_content,
                'order' => $order_content
            ],
            'section' => [
                'id'    => $id_section,
                'order' => $order_section
            ],
            'unit' => [
                'id'    => $id_unit,
                'order' => $order_unit
            ],
            'level' => [
                'id'    => $id_level,
                'order' => $order_level
            ],
        ]
    ];
}

function delete_user_answers_by_unit_id($conn,$id_student,$id_unit){
    $sql_delete_answers = "DELETE FROM answers
    WHERE id_user = '{$id_student}' AND
    id_content IN (
            SELECT id_content
            FROM contents c
            INNER JOIN sections s USING(id_section)
            INNER JOIN units u USING(id_unit)
            WHERE u.id_unit = '{$id_unit}'
        )
    ";
    if(!mysqli_query($conn,$sql_delete_answers)){
        $error = mysqli_error($conn);
        mysqli_rollback($conn);
        mysqli_close($conn);
        http_response_code(500);
        die(json_encode([
            'debug' => $error
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }

    // EMPTY UNIT PROGRESS
        $user_progress = fetch_user_progress($id_student,$conn);
        $unit_progress = $user_progress['unitProgress'];
        if($unit_progress != 'null' && $unit_progress != null){
            $json_progress = json_decode($unit_progress,true);
            unset($json_progress[$user_progress['id_unit']]);
            $unit_progress = json_encode($json_progress, JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES);
        }

        $sql_update = "UPDATE user_progress SET units_progress = '{$unit_progress}' WHERE id_user = '{$id_student}';";
        
        if(!mysqli_query($conn,$sql_update)){
            $error = mysqli_error($conn);
            mysqli_rollback($conn);
            mysqli_close($conn);
            http_response_code(500);
            die(json_encode([
                'debug' => $error
            ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
        }
    //

    return true;
}

function delete_user_answers_by_section_id($conn,$id_student,$id_section){
    $sql_delete_answers = "DELETE FROM answers
    WHERE id_user = '{$id_student}' AND
    id_content IN (
            SELECT id_content
            FROM contents c
            INNER JOIN sections s USING(id_section)
            WHERE s.id_section = '{$id_section}'
        )
    ";
    if(!mysqli_query($conn,$sql_delete_answers)){
        $error = mysqli_error($conn);
        mysqli_rollback($conn);
        mysqli_close($conn);
        http_response_code(500);
        die(json_encode([
            'debug' => $error
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }

    return true;
}

function delete_user_answers_by_content_id($conn,$id_student,$id_content){
    $sql_delete_answers = "DELETE FROM answers
    WHERE id_user = '{$id_student}' AND
    id_content = '{$id_content}'
    ";
    if(!mysqli_query($conn,$sql_delete_answers)){
        $error = mysqli_error($conn);
        mysqli_rollback($conn);
        mysqli_close($conn);
        http_response_code(500);
        die(json_encode([
            'debug' => $error
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }

    return true;
}

function test_editor_permition($conn,$id_user){
    $sql_get = "SELECT 
    editor
    FROM users 
    WHERE id_user = '{$id_user}';";

    $result_get = mysqli_query($conn,$sql_get);

    if(!$result_get){
        return [
            'status' => 500,
            'response' => [],
            'debug' => $sql_get
        ];        
    }

    $row_get = mysqli_fetch_assoc($result_get);

    $editor = $row_get['editor'];

    if($editor != 1){
        return [
            'status'    => 200,
            'response'  => [
                'permition' => false
            ]
        ];
    }else{
        return [
            'status'    => 200,
            'response'  => [
                'permition' => true
            ]
        ];
    }
}

function send_end_email($conn,$id_student){

    $sql_student = " SELECT u.`name`, u.email, up.`units_progress`,
     (SELECT average FROM current_average) as average,
     (SELECT content FROM email_templates WHERE id_email_template = '69e30a79-3a49-11ed-affa-00e04c0362fc') as template_email,
     (SELECT `subject` FROM email_templates WHERE id_email_template = '69e30a79-3a49-11ed-affa-00e04c0362fc') as template_subject
    FROM users u INNER JOIN user_progress up USING(id_user) WHERE u.id_user = '{$id_student}';
    ";


    $result_student = mysqli_query($conn,$sql_student);

    if(!$result_student){
        return false;
    }

    $row_student = mysqli_fetch_assoc($result_student);
    $content = $row_student['template_email'];
    $email = $row_student['email'];
    $media = $row_student['average'];
    $subject = $row_student['template_subject'];
    $nome = $row_student['name'];

    $unit_progress = json_decode($row_student['units_progress'],true);
    $counter = 0;
    $sum_average = 0;

    $html_table = '
        <table>
            <thead>
                <th>
                    Unit
                </th>
                <th>
                    Nota
                </th>
            </thead>
            <tbody>
                            
    ';

    $sql_units = "SELECT label, id_unit FROM units;";
    $result_units = mysqli_query($conn,$sql_units);
    if(!$result_units){
        return false;
    }

    $json_units = [];

    while($row_units = mysqli_fetch_assoc($result_units)){
        $json_units[$row_units['id_unit']] = $row_units['label']; 
    }

    foreach($unit_progress as $id_unit => $unit){
        
        $nome_unit = $json_units[$id_unit];

        if($nome_unit != null){
            $html_table .= '
                <tr>
                    <td style="text-align:center">
                        '.$nome_unit.'
                    </td>
                    <td style="text-align:center">
                        '.$unit['grade'].'    
                    </td>
                </tr>
            ';
    
            $counter ++;
            $sum_average += $unit['grade'];

        }

    }

    $html_table .= '
        </tbody>
        </table>
    ';

    $average = $sum_average/$counter;
    
    $subject = str_replace("{{nome}}", $nome, $subject);

    $content = str_replace("{{nome}}", $nome, $content);
    $content = str_replace("{{media}}", $media, $content);
    $content = str_replace("{{media-f}}", $average, $content);
    
    $content .= $html_table;

    $html_email = create_body_email($content);

    file_put_contents(__DIR__ . '/send_end_email.html', $html_email);

    return enviar_email($email,$html_email,$subject,null);

}

function send_register_email($conn,$url_alt,$senha,$nome,$email){
    $sql_student = "SELECT content, `subject` FROM email_templates WHERE id_email_template = '2d31f0ae-3159-11ed-9b2d-00e04c0362fc';";

    $result_student = mysqli_query($conn,$sql_student);

    if(!$result_student){
        return mysqli_error($conn);
    }

    $link = create_button($url_alt,'Acessar');

    $row_student = mysqli_fetch_assoc($result_student);
    $content = $row_student['content'];
    $subject = $row_student['subject'];

    $content = str_replace("{{nome}}", $nome, $content);
    $subject = str_replace("{{nome}}", $nome, $subject);

    $content = str_replace("{{email}}", $email, $content);
    $content = str_replace("{{senha}}", $senha, $content);
    $content = str_replace("{{link}}", $link, $content);

    $html_email = create_body_email($content);

    file_put_contents(__DIR__ . '/send_register_email.html', $html_email);

    return enviar_email($email,$html_email,$subject,null);

}

function send_finish_unit_email($conn,$id_student,$url_alt){
    $sql_student = "SELECT us.`name`,
        us.email,
        up.`units_progress`,
        (SELECT average FROM current_average) as c_average,
        (SELECT content FROM email_templates WHERE id_email_template = '915ed6d6-3290-11ed-9b2d-00e04c0362fc') as content_up,
        (SELECT `subject` FROM email_templates WHERE id_email_template = '915ed6d6-3290-11ed-9b2d-00e04c0362fc') as content_up_subject,
        (SELECT content FROM email_templates WHERE id_email_template = '1fbbeabc-3a49-11ed-affa-00e04c0362fc') as content_down,
        (SELECT `subject` FROM email_templates WHERE id_email_template = '1fbbeabc-3a49-11ed-affa-00e04c0362fc') as content_down_subject,
        u.id_unit,
        u.label
        FROM users us
        INNER JOIN user_progress up USING(id_user)
        INNER JOIN levels l ON up.level_order = l.order 
        INNER JOIN units u ON u.id_level = l.id_level AND u.order = up.unit_order
        WHERE us.id_user = '{$id_student}'
        GROUP BY us.id_user;
    ";

    $result_student = mysqli_query($conn,$sql_student);

    if(!$result_student){
        return false;
    }

    $row_student = mysqli_fetch_assoc($result_student);

    $email = $row_student['email'];
    $nome = $row_student['name'];
    
    $id_unit = $row_student['id_unit'];
    $label = $row_student['label'];

    $content_up = $row_student['content_up'];
    $content_down = $row_student['content_down'];
    
    $content_up_subject = $row_student['content_up_subject'];
    $content_down_subject = $row_student['content_down_subject'];
    
    $c_average = $row_student['c_average'];

    $url_unit = $url_alt.'teo/unit/'.$id_unit;
    $link = create_button($url_unit,'Acessar Unit');

    $unit_progress = json_decode($row_student['units_progress'],true);

    $grade = $unit_progress[$id_unit]['grade'];

    if($grade < $c_average){
        $subject = $content_down_subject;
        $content = $content_down;
    }else{
        $subject = $content_up_subject;
        $content = $content_up;
    }

    $subject = str_replace("{{nome}}", $nome, $subject);

    $content = str_replace("{{nome}}", $nome, $content);
    $content = str_replace("{{nota}}", $grade, $content);
    $content = str_replace("{{unit}}", $label, $content);
    $content = str_replace("{{media}}", $c_average, $content);
    $content = str_replace("{{link}}", $link, $content);

    $html_email = create_body_email($content);

    file_put_contents(__DIR__ . '/send_finish_unit_email.html', $html_email);

    return enviar_email($email,$html_email,$subject,null);

}

function send_reset_unit_email($conn,$id_student,$id_unit,$url_alt){
    $sql_student = " SELECT us.`name`,
        us.email,
        (SELECT content FROM email_templates WHERE id_email_template = 'd9e6d397-3a49-11ed-affa-00e04c0362fc') as email_content,
        (SELECT `subject` FROM email_templates WHERE id_email_template = 'd9e6d397-3a49-11ed-affa-00e04c0362fc') as email_subject,
        (SELECT label FROM units WHERE id_unit = '{$id_unit}') as unit_label
        FROM users us
        WHERE us.id_user = '{$id_student}'
        GROUP BY us.id_user;
        
    ";

    $result_student = mysqli_query($conn,$sql_student);

    if(!$result_student){
        return mysqli_error($conn);
    }

    if(mysqli_num_rows($result_student) < 1){
        return false;
    }

    $row_student = mysqli_fetch_assoc($result_student);

    $name = $row_student['name'];
    $email = $row_student['email'];
    $content = $row_student['email_content'];
    $subject = $row_student['email_subject'];
    $unit_label = $row_student['unit_label'];
    $url_unit = $url_alt.'teo/unit/'.$id_unit;

    $link = create_button($url_unit,'Acessar Unit');

    $subject = str_replace("{{nome}}", $name, $subject);
    $subject = str_replace("{{unit}}", $unit_label, $subject);

    $content = str_replace("{{nome}}", $name, $content);
    $content = str_replace("{{unit}}", $unit_label, $content);
    $content = str_replace("{{link}}", $link, $content);
    
    $html_email = create_body_email($content);
    return enviar_email($email,$html_email,$subject,null);
    // return $html_email;

}

function send_pass_recover_email($conn,$email,$url_alt){
    $sql_student = "SELECT recover_code, `name` FROM users WHERE email = '{$email}';";

    $result_student = mysqli_query($conn,$sql_student);

    if(!$result_student){
        return false;
    }

    $row = mysqli_fetch_assoc($result_student);

    $code = $row['recover_code'];
    $name = $row['name'];

    $url_recover = $url_alt . 'auth/recover/' . $code;

    $link = create_button($url_recover,'Alterar senha');

    $content = "
        <p>Olá {$name}!</p>
        <p>Você solicitou recentemente um link para troca de senha. <br/> Clique no botão abaixo para redefinir sua senha, o link estará disponível apenas por 24 horas.</p>
        <br/>
        {$link}
    ";

    $html_email = create_body_email($content);

    file_put_contents(__DIR__ . '/recover_pass.html', $html_email);

    return enviar_email($email,$html_email,"Recuperação de senha TEO",null);
    // return true;

}

function send_bug_email($conn,$id_user,$link,$path,$description){
    $sql_student = "SELECT `name`, email FROM users WHERE id_user = '{$id_user}';";

    $result_student = mysqli_query($conn,$sql_student);

    if(!$result_student){
        return false;
    }

    $row = mysqli_fetch_assoc($result_student);

    $name = $row['name'];
    $email = $row['email'];

    $link = create_button($link,'Acessar página do erro');

    $content = "
        <p>Usuário: {$name}</p>
        <p>E-mail: {$email}</p>
        <br/>
        <p>Relato: {$description}</p>
        <br/>
        <p>Caminho: {$path}</p>

        {$link}
    ";

    $html_email = create_body_email($content);

    file_put_contents(__DIR__ . '/bug_report.html', $html_email);

    return enviar_email('contato@twenty.net.br',$html_email,"Reporte de Bug TEO",null);

}

function getRequestHeaders() {
    $headers = array();
    foreach($_SERVER as $key => $value) {
        if (substr($key, 0, 5) <> 'HTTP_') {
            continue;
        }
        $header = str_replace(' ', '-', ucwords(str_replace('_', ' ', strtolower(substr($key, 5)))));
        $headers[$header] = $value;
    }
    return $headers;
}

function test_header_key(){
    $headers = getRequestHeaders();
    if(isset($headers['X-Api-Key'])){
        if($headers['X-Api-Key'] != 'KLD__F4SDs@sdA'){
            http_response_code(403);
            die();
        }
    }else{
        http_response_code(403);
        die();
    }
}

?>
