<?php

header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: *");

include_once __DIR__ . '/../../config/db-connection.php';
include_once __DIR__ . '/../../config/https_environment.php';
include_once __DIR__ . '/../../utils/utils.php';

//CHECK API KEY
test_header_key();

$json = file_get_contents('php://input');
    
$json = json_decode($json,true);

if(empty($json['id_user'])){
    http_response_code(400);
    die(json_encode([
        'debug' => 'id_user'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

if(empty($json['id_unit'])){
    http_response_code(400);
    die(json_encode([
        'debug' => 'id_unit'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

$id_user = mysqli_real_escape_string($conn,$json['id_user']);
$id_unit = mysqli_real_escape_string($conn,$json['id_unit']);
// $id_user = 'a6c90136-f0c8-11ec-a869-00e04c0362fc';
// $id_unit = '07678cc9-f15b-11ec-a0db-00e04c0362fc';

// GET UNIT SECTIONS DATA
    $sql_sections = "SELECT 
        l.`label` as level_label,
        l.`order` as level_order,
        l.`class_name`,
        u.`order` as unit_order,
        u.`label` as unit_label,
        s.`id_section`,
        s.`label` as section_label,
        s.`order` as section_order,
        s.icon
        FROM sections s
        INNER JOIN units u USING(id_unit)
        INNER JOIN levels l USING(id_level)
        WHERE u.`id_unit` = '${id_unit}' AND
        s.`status` = 1 AND
        u.`status` = 1 AND
        l.`status` = 1
        ORDER BY s.`order` ASC;
    ";

    $result_sections = mysqli_query($conn,$sql_sections);

    if(!$result_sections){
        http_response_code(500);
        die(json_encode([
            'debug' => $sql_sections
        ],JSON_UNESCAPED_UNICODE));
    }

    while($row_section = mysqli_fetch_assoc($result_sections)){
        $level_label = $row_section['level_label'];
        $level_order = $row_section['level_order'];
        $unit_label = $row_section['unit_label'];
        $unit_order = $row_section['unit_order'];
        $color_class = $row_section['class_name'];

        $section_id = $row_section['id_section'];
        $section_label = $row_section['section_label'];
        $section_order = $row_section['section_order'];
        $section_icon = $row_section['icon'];
        $json_sections[$section_id] = [
            "name" =>  $section_label,
            "order" =>  $section_order,
            "iconClass" => $section_icon
        ];
    }

// GET USER PROGRESS PERMITION
    $result_user_progress = get_user_progress($id_user,$url);

    if($result_user_progress['status'] != 200){
        http_response_code($result_user_progress['status']);
        die(json_encode([
            'debug' => $result_user_progress['debug']
        ], JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES));
    }

    // $user_progress_json = json_decode($user_progress, true);
    $user_progress_json = $result_user_progress['response']['user_progress'];
    $user_unit_progress = json_decode($user_progress_json['unitProgress'],true);
    $user_progress = $user_progress_json['progress'];

// TEST USER PROGRESS PERMITION
    $user_progress_authorized = check_user_permission_material([
        'level' => $level_order,
        'unit' => $unit_order
    ],$user_progress);

    if(!$user_progress_authorized){
        http_response_code(403);
        mysqli_close($conn);
        die(json_encode([
            'debug' => 'user progress 403'
        ], JSON_UNESCAPED_UNICODE, JSON_UNESCAPED_SLASHES));
    }

// END OPERATION
    http_response_code(200);
    mysqli_commit($conn);
    mysqli_close($conn);
    die(json_encode([
        "levelName"     => $level_label,
        "levelOrder"    => $level_order,
        "unitName"      => $unit_label,
        "unitOrder"     => $unit_order,
        "colorClass"    => $color_class,
        "sections"      => $json_sections
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));

?>