<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: *");

include_once __DIR__ . '/../../config/db-connection.php';
include_once __DIR__ . '/../../config/https_environment.php';
include_once __DIR__ . '/../../utils/utils.php';

//CHECK API KEY
test_header_key();

$json = file_get_contents('php://input');
    
$json = json_decode($json,true);

if(empty($json['id_user'])){
    http_response_code(400);
    die(json_encode([
        'debug' => 'id_user'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}
$id_user = mysqli_real_escape_string($conn,$json['id_user']);

if(empty($json['admin_data'])){
    http_response_code(400);
    die(json_encode([
        'debug' => 'admin_data'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}
$admin_data = $json['admin_data'];

$cpf = 'NULL';
if(isset($admin_data['cpf'])){
    $cpf = mysqli_real_escape_string($conn,$admin_data['cpf']);
    $cpf = "'{$cpf}'";
}

if(isset($admin_data['name'])){
    $name = mysqli_real_escape_string($conn,$admin_data['name']);
}else{
    http_response_code(400);
    die(json_encode([
        'debug' => 'name'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

$birth = 'NULL';
if(isset($admin_data['birth'])){
    $birth = $admin_data['birth'];
    $birth = str_replace('/','-',$birth);
    $birth = strtotime($birth);
    $birth = date('Y-m-d',$birth);
    $birth = "'{$birth}'";
}

if(isset($admin_data['email'])){
    $email = mysqli_real_escape_string($conn,$admin_data['email']);
}else{
    http_response_code(400);
    die(json_encode([
        'debug' => 'email'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

$phone = "NULL";
if(isset($admin_data['phone'])){
    $phone = mysqli_real_escape_string($conn,$admin_data['phone']);
    $phone = "'{$phone}'";
}

$city = 'NULL';
if(isset($admin_data['city'])){
    $city = mysqli_real_escape_string($conn,$admin_data['city']);
    $city = "'{$city}'";
}

$state = "NULL";
if(isset($admin_data['state'])){
    $state = mysqli_real_escape_string($conn,$admin_data['state']);
    $state = "'{$state}'";
}

$editor = 0;
if(isset($admin_data['editor'])){
    $editor = $admin_data['editor'] == true ? 1 : 0;
}

if(isset($admin_data['group'])){
    $group = mysqli_real_escape_string($conn,$admin_data['group']);
    $group = intval($group);
    $sql_group = "SELECT id_group FROM `groups` WHERE `level` = {$group} LIMIT 1";
    $result_group = mysqli_query($conn,$sql_group);
    if(!$result_group){
        $error = mysqli_error($conn);
        http_response_code(500);
        mysqli_rollback($conn);
        mysqli_close($conn);
        die(json_encode([
            'debug_sql' => $error,
            'debug' => 'error getting group id',
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }
    if(mysqli_num_rows($result_group) < 1){
        $error = mysqli_error($conn);
        http_response_code(400);
        mysqli_rollback($conn);
        mysqli_close($conn);
        die(json_encode([
            'message' => 'Ocorreu um problema ao selecionar o grupo do usuário.'
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }
    $row_group = mysqli_fetch_assoc($result_group);
    $id_group = $row_group['id_group'];
}else{
    http_response_code(400);
    die(json_encode([
        'debug' => 'group'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

$id_code = "null";

if(isset($admin_data['password'])){
    $password = mysqli_real_escape_string($conn,$admin_data['password']);
}

// TEST USER PERMITION

    $test_permition = test_permition($conn,$id_user,3);
    if($test_permition['status'] != 200){
        mysqli_close($conn);
        http_response_code(500);
        die(json_encode([
            'debug' => $test_permition
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }
    if(!$test_permition['response']['permition']){
        mysqli_close($conn);
        http_response_code(403);
        die(json_encode([
            'debug' => 'permition'
        ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
    }
    
//

$sql_verify = "SELECT id_user FROM users WHERE email = '{$email}';";

$result_verify = mysqli_query($conn,$sql_verify);
if(!$result_verify){
    $error = mysqli_error($conn);
    http_response_code(500);
    mysqli_rollback($conn);
    mysqli_close($conn);
    die(json_encode([
        'debug' => 'email verify',
        'debug_error' => $error
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

if(mysqli_num_rows($result_verify) > 0){
    $error = mysqli_error($conn);
    http_response_code(400);
    mysqli_rollback($conn);
    mysqli_close($conn);
    die(json_encode([
        'message' => 'O endereço de e-mail já está em uso.'
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

$sql_create = "CALL sp_create_user('{$id_user}','{$id_group}',{$editor},{$cpf},'{$name}','{$email}',{$phone}, md5('{$password}'),{$city},{$state},null,{$birth},1)";

$result_create = mysqli_query($conn,$sql_create);

if(!$result_create){
    $error = mysqli_error($conn);
    http_response_code(500);
    mysqli_rollback($conn);
    mysqli_close($conn);
    die(json_encode([
        'debug' => $error,
        'debug_sql' => $sql_create
    ],JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES));
}

http_response_code(200);
mysqli_commit($conn);
mysqli_close($conn);

die();

?>

